@@ -15,7 +15,9 @@ namespace libetonyek
 IWORKDictionary::IWORKDictionary()
   : m_characterStyles()
   , m_graphicStyles()
+  , m_layoutStyles()
   , m_paragraphStyles()
+  , m_vectorStyles()
   , m_stylesheets()
   , m_beziers()
   , m_data()
